#
# spec file for package leechcraft-doc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define LEECHCRAFT_VERSION 0.6.70-17609-g3dde4097dd

Name:           leechcraft-doc
Version:        0.6.70+git.17609.g3dde4097dd
Release:        1.1
Summary:        Modular Internet Client Documentation
License:        BSL-1.0
Group:          Development/Libraries/Other
URL:            https://leechcraft.org
Source0:        https://dist.leechcraft.org/LeechCraft/0.6.75/leechcraft-%{LEECHCRAFT_VERSION}.tar.xz

BuildRequires:  doxygen >= 1.8.3.1
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  xz
BuildArch:      noarch

%description
This packages provides documentation of LeechCraft core API.

It contains description of core API used for developing first-level
LeechCraft plugins. For developing sub-plugins, please refer to
corresponding packages (like leechcraft-azoth-doc). This documentation
is also available online at http://doc.leechcraft.org/core/

%package -n leechcraft-azoth-doc
Summary:        LeechCraft Azoth Documentation
Group:          Development/Libraries/Other
BuildArch:      noarch

%description -n leechcraft-azoth-doc
This packages provides documentation of LeechCraft Azoth API.

It contains description of Azoth API used for developing LeechCraft
Azoth sub-plugins. For developing first-lexel plugins, please refer
to corresponding packages (like leechcraft-doc). This documentation
is also available online at http://doc.leechcraft.org/azoth/

%package -n leechcraft-monocle-doc
Summary:        LeechCraft Monocle Documentation
Group:          Development/Libraries/Other
BuildArch:      noarch

%description -n leechcraft-monocle-doc
This packages provides documentation of LeechCraft Monocle API.

It contains description of Monocle API used for developing LeechCraft
Monocle sub-plugins. For developing first-lexel plugins, please refer
to corresponding packages (like leechcraft-doc). This documentation
is also available online at http://doc.leechcraft.org/monocle/

%prep
%setup -q -n leechcraft-%{LEECHCRAFT_VERSION}

%build
cd doc/doxygen/core
sed -i Doxyfile \
-e "s/PROJECT_NUMBER .*/PROJECT_NUMBER         = %{LEECHCRAFT_VERSION}/"
doxygen Doxyfile

cd ../azoth
sed -i Doxyfile \
-e "s/PROJECT_NUMBER .*/PROJECT_NUMBER         = %{LEECHCRAFT_VERSION}/"
doxygen Doxyfile

cd ../monocle
sed -i Doxyfile \
-e "s/PROJECT_NUMBER .*/PROJECT_NUMBER         = %{LEECHCRAFT_VERSION}/"
doxygen Doxyfile

%install
cd doc/doxygen/core/out/html
mkdir -p %{buildroot}%{_docdir}/leechcraft-doc
cp -r * %{buildroot}%{_docdir}/leechcraft-doc

cd ../../../azoth/out/html
mkdir -p %{buildroot}%{_docdir}/leechcraft-azoth-doc
cp -r * %{buildroot}%{_docdir}/leechcraft-azoth-doc

cd ../../../monocle/out/html
mkdir -p %{buildroot}%{_docdir}/leechcraft-monocle-doc
cp -r * %{buildroot}%{_docdir}/leechcraft-monocle-doc

%fdupes -s %{buildroot}%{_docdir}/leechcraft-doc/
%fdupes -s %{buildroot}%{_docdir}/leechcraft-azoth-doc/
%fdupes -s %{buildroot}%{_docdir}/leechcraft-monocle-doc/

%files
%doc %{_docdir}/leechcraft-doc

%files -n leechcraft-azoth-doc
%doc %{_docdir}/leechcraft-azoth-doc

%files -n leechcraft-monocle-doc
%doc %{_docdir}/leechcraft-monocle-doc

%changelog
* Mon Jun 16 2025 Dmitriy Perlow <dap.darkness@gmail.com>
- Leap 16 build via gcc15.
* Mon Jun 16 2025 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-0.6.70-17609-g3dde4097dd snapshot:
  * Compilation failure fix;
  * Old plugins revived: Blasq-Spegnersi (Flickr) & Hotsensors;
  * New plugins enabled: Tracolor & Azoth-Fontiac;
- LastFM-Qt6 build condition removed since liblastfm-qt6-devel
  became available.
* Thu Mar 13 2025 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-17335-ge406ffdcaf snapshot:
  * Boost fix;
  * Qt6 instead of Qt5:
    + LastFM-Qt6 & ProjectM-Qt6 build conditions introduced
    since respective Qt6 libraries are not available now;
    + Azoth-juick, krigstask, poshuku-qrd became obsoleted;
    + Qt5WebKit build condition removed;
    + Since Qt6WebEngine is available only for x86_64 & aarch64
    azoth, lhtr & poshuku became obsoleted for ppc, ppc64,
    ppc64le, s390, s390x, i586, armv6l & armv7l;
- Dropped obsoletions for unsupported distibutions;
- Removed leechcraft-0.6.70-16373-g319c272718-build.patch;
- Removed lc_plugin_wrapper-qt5.1.
* Fri Mar 22 2024 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-16373-g319c272718 snapshot:
  * TagLib fix;
  * LeechCraft Azoth MrIM Module (vader) became obsoleted;
  * Monocle Boop contains a EPub subplugin for documents viewer;
  * Set -DWITH_DBUS_LOADERS=False to fix compilation.
  * Added leechcraft-0.6.70-16373-g319c272718-build.patch to fix
    compilation of Azoth plugin.
  * Dropped obsoletions for unsupported distibutions;
  * Fixed 'E: unused-rpmlintrc-filter "filename-too-long-for-joliet"'.
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Tue Aug 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing libavresample build dependency.
  Needed to build leechcraft with FFmpeg 5.
- Drop leechcraft-doc.changes. The build service no longer
  complains when a package with different spec files only has one
  changelog file
- Partial spec cleanup
* Fri Oct 29 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-14794.g33744ae6ce snapshot:
  * Qt5WebKit bcond.
* Tue Aug 31 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-14771-g9d21b0f8ad snapshot:
  * libtorrent-rasterbar 2 support;
  * bittorrent plugin for ppc64 enabled;
  * kinotify & azoth don't require Qt5WebKitWidgets any more;
  * some tests were fixed & enabled;
  * azoth not for architectures without QtWebEngine now;
  * poshuku-foc plugin (adobe flash) became deprecated.
- Removed leechcraft-libtorrent-legacy.patch
* Thu Jul 29 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Obsoletes poshuku (browser) for architectures without QtWebEngine.
* Mon Jul 19 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-14675-g3f93af1b45 snapshot:
  * Utils tests became broken (reported to upstream and disabled);
  * Qwt 6.2.0 support;
  * Fixed build via gcc 11.
- Macros %%%%cmake_build & %%%%ctest.
* Thu Jul  1 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- QtWebkit will be removed from openSUSE Tumbleweed soon.
* Tue Jun 29 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Disabled qml requires.
* Tue Jun 22 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-14522-g3ce98b2ddb snapshot:
  * Qt 5.12 (Leap 15.*) compatibility no more, deleted
    leechcraft-Qt5_12.patch & leechcraft-qtermwidget-Leap-15_2.patch ;
  * Gcc 10 temporarily untill upstream gcc 11 compatibility fix;
  * Сmake options clean-up;
  * Source-url is back.
* Fri Sep 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Use legacy libtorrent-rasterbar on Tumbleweed
- Add leechcraft-libtorrent-legacy.patch
* Thu Sep 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Fix build with new libqxmpp
* Thu May 21 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13907-g785196c688 snapshot:
  * Current source-url provides 0.6.70-13870-ga08049301b.
  * Pkgconfig for XCB, X11, udev, libguess, taglib, libmtp,
    libprojectM, qtermwidget (doesn't work for Leap, so patched back),
    pcre, libtorrent, maxminddb, libpurple, qca2, qxmpp, tox.
  * Added leechcraft-Qt5_12.patch to save Qt 5.12 compatibility.
  * Added leechcraft-qtermwidget-Leap-15_2.patch for Leap 15.2.
  * Unembed some resources.
* Fri May  1 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13729-g7046a9d2a7 snapshot:
  * Imgaste & Azoth AP backends fixes.
  * Source-url is back.
* Tue Mar 31 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13641-g995b95b3d4 snapshot:
  * MaxMindDB instead of GeoIP;
  * There will not be source-url till Saturday.
* Tue Mar 10 2020 Vítězslav Čížek <vcizek@suse.com>
- Drop support for GeoIP in BitTorrent, GeoIP is obsolete (bsc#1156208)
* Mon Feb  3 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13588-g98cf733e94 snapshot:
  * Qt 5.14 compatibility;
  * Overall code refactoring.
* Wed Dec 25 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Refactored changes file.
- Updated to 0.6.70-13588-g98cf733e94 snapshot:
  * Aggregator WA (fixed cmake search after wt 4.2 update);
  * LMP (drop support for taglib < 1.6);
  * Overall code refactoring.
- Raised qxmpp version required to build to fix Leap 15.1.
* Wed Nov  6 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Kwin package name was fixed (kwin => kwin5)
- Fixed previous changelog entry.
* Fri Nov  1 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Leap 15.2-15.3 may become resolvable:
  there will be no gcc >= 8 out of box at any Leap 15.*.
* Mon May 27 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Use GCC >= 8 for suse_version > 1500 (i.e. Tumbleweed and
  CODE16).
* Sat May 11 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13186-g2c3ee31903 snapshot.
- Qt4 EOL: qxmpp-qt5 was renamed into qxmpp.
- Removed leechcraft-Qt59.diff (upstreamed).
* Sun Apr 14 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13163-g100049e6a6 snapshot:
  * Fixed Leap compiller errors;
  * Added leechcraft-Qt59.diff to get Leap build;
  * Fixed mode of sha1 _service.
* Sat Apr  6 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated to 0.6.70-13143-gd05082db2d snapshot:
  * ppc64 & arm were fixed via plugins disabling;
  * Added _service with sha1;
  * vGrabber plugin became obsoleted;
  * gcc ≥ 8 became requred to build;
  * Qt ≥ 5.10 became requred to build;
  * Utils tests are back (libQt5Sql5-sqlite became requires).
* Sun Mar 24 2019 dap.darkness@gmail.com
- Removed leechcraft-projectM-qt5.patch
  because projectM became Qt5' one.
* Fri Feb 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Use newer projectM where available
* Sun Jun 10 2018 dap.darkness@gmail.com
- Updated to 0.6.70-11552-gf61ee51c3d snapshot:
  * Qt 5.11 configure issue should be resolved.
- Right cmake & Qt minimal versions.
* Tue Feb 13 2018 aloisio@gmx.com
- Added leechcraft-projectM-qt5.patch
* Tue Jan 23 2018 dap.darkness@gmail.com
- Updated to 0.6.70-10870-g558588d6ec snapshot:
  * Utils tests became temporarily disabled (wip);
  * cmake ≥ 3.10 became required to build;
  * Wt build failure was fixed;
  * Bug #2048 may be resolved (xoox log failure);
  * Azoth tab closing segfault may be fixed;
  * Bug #2045 was resolved (poshuku start-up segfault).
* Wed Nov 29 2017 dimstar@opensuse.org
- BuildIgnore openssl: the required libraries are pulled in by wt
  and libqt. openssl (the program suite) is not required here.
* Sun Aug 13 2017 dap.darkness@gmail.com
- Updated to 0.6.70-9561-gaf7a4f70b8 git snapshot:
  * Bug #2042 was resolved (segfault on Qt 5.6 → 5.9 update).
- Monocle plugin requires gcc ≥ 7.
- Let's use Qt5 lastfm library.
- Enabled back plugins since Qt5Qwt6 became available:
  * lemon — another network Monitor;
  * liznoo — power manager.
* Thu Aug 10 2017 dap.darkness@gmail.com
- Harbinger became really obsoleted now.
- Added Qt5 runtime requirements.
- Updated to 0.6.70-9432-g81ef79f367 git snapshot:
  * Bugged contacts could be hidden now.
  * Bug #1348 was resolved (no birthday notifications);
  * Right main man page file name.
* Tue Jul 25 2017 tchvatal@suse.com
- Do not recommend fluendo plugins as now mp3 is enabled by default
* Sat Jun 24 2017 dap.darkness@gmail.com
- Updated to 0.6.70-9312-g4cc613a2df git snapshot:
  * Bug #2038 was resolved (Segfault: IRC → offline);
  * %%%%check section: output on failure;
  * %%%%check section: more tests enabled.
* Mon Jun  5 2017 dap.darkness@gmail.com
- Updated to 0.6.70-9233-gffda87bea6 git snapshot:
  * gcc7 fix;
  * Qt5;
  * buildrequires&obsoletes clean-up;
  * GPTOOLS_MEM;
  * %%%%check section;
  * CXX 17.
- Obsoleted plugins:
  * azoth-astrality (no Qt5 telepathy);
  * harbinger;
  * lemon (no Qt5 qwt);
  * liznoo (no Qt5 qwt);
  * popishu (Qt5 Scintilla includes failure);
  * qrosp (no Qt5 qross);
  * vtyulc (no code maintainer).
- New plugins:
  * lmp-ppl (Portable Player Logging support);
  * namauth (standard HTTP authentication facilities);
  * poshuku-foc (Flash-on-Click);
  * poshuku-webkitview (WebKit-based backend).
- Removed patched:
  * leechcraft-0.6.70-6645-gcd10d7e-boost161.diff
  * leechcraft-0.6.70-6645-gcd10d7e-hunspell17.diff
  * leechcraft-0.6.70-6645-gcd10d7e-torrent110.diff
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Jan  4 2017 dap.darkness@gmail.com
- Updated leechcraft-0.6.70-6645-gcd10d7e-hunspell14.diff and
  renamed into leechcraft-0.6.70-6645-gcd10d7e-hunspell17.diff
* Sun Aug 21 2016 dap.darkness@gmail.com
- Added leechcraft-0.6.70-6645-gcd10d7e-boost161.diff
  for newest boost support.
* Sun Jul 31 2016 jengelh@inai.de
- Update summaries and descriptions: rectify grammar and remove
  redundant mentions.
- Avoid sh invocation for simple ldconfig calls.
* Mon Jul 25 2016 olaf@aepfle.de
- Unconditionally build with ffmpeg
* Mon Jul  4 2016 dap.darkness@gmail.com
- Updated leechcraft-0.6.70-6645-gcd10d7e-torrent110.diff & added
  BOOST_ASIO_HAS_STD_CHRONO vs. bittorrent initialization failure.
- Cmake clean-up.
- Man pages clean-up.
* Sat Jun 11 2016 dap.darkness@gmail.com
- Dropped openSUSE 13.1 & SLE because of no valid compiler.
- Enabled more packages for openSUSE Leap 42.
- Recommended extra engines for lmp.
- Added rpmlintrc to silence useless warnings.
- Added simple man pages.
* Sat May  7 2016 dap.darkness@gmail.com
- Updated to 0.6.70-6645-gcd10d7e git snapshot:
  (NOTE: the latest one supporting gcc 4.8
  i.e. openSUSE 13.1, 13.2 & Leap 42.1)
- Azoth Herbicide required boost ≥ 1.58
  and was disabled for 13.1, 13.2 & Leap 42.1 so.
- Added leechcraft-0.6.70-6645-gcd10d7e-torrent110.diff
  for newest torrent rasterbar support.
- Added leechcraft-0.6.70-6645-gcd10d7e-hunspell14.diff
  for newest hunspell support.
* Wed Feb  3 2016 dap.darkness@gmail.com
- Updated to 0.6.70-6053-g34d21e8 git snapshot:
  * Threads utility was split out.
  * Taglib >= 1.10 became supported.
- Musiczombie plugin chromaprint future was enabled for Factory.
- C++14 code and xproxy plugin were enabled for Factory.
- leechcraft-lmp-append-gstreamer-include-dirs-pkgconfig.patch
  was removed as already provided via upstream tarball.
* Sun Nov 29 2015 mlin@suse.com
- Add leechcraft-lmp-append-gstreamer-include-dirs-pkgconfig.patch
  * Fix compilation in lmp plugin with GStreamer 1.5.1 and above
* Fri Aug 21 2015 normand@linux.vnet.ibm.com
- bypass bug 927268 for PowerPC if clang used in place of gcc
  for build ppc64le architecture and (suse_version} <= 1320
* Thu Jul  2 2015 dap.darkness@gmail.com
- Fixed openSUSE <= 13.2 builds & pcc x32.
* Wed Jul  1 2015 pth@suse.de
- Build with gcc/g++ at least for the time being to avoid compiler
  error. But use it only if suse_version > 1320.
* Wed Jun 10 2015 dap.darkness@gmail.com
- Updated to 0.6.70-3565-g2d86529 git snapshot.
- Utils postfix macros were introduced,
  devel subpackage requirements were fixed.
* Mon May 25 2015 dap.darkness@gmail.com
- Updated to 0.6.70-3466-g864bd1a git snapshot:
  * clang seems to be better C++ compiler;
  * Dolozhee plugin got https support and was fixed so.
- New plugins were enabled:
  * snails — e-mail client.
- C++14 support (gcc >= 4.9 is required).
* Tue Apr 21 2015 dap.darkness@gmail.com
- Updated to 0.6.70-2742-gfaed6e2 git snapshot
  to resolve openSUSE Factory build time issue.
- More directories macro using to be ready for Qt5 release.
- Dropped openSUSE < 13.1, removed useless patches:
  * leechcraft-azoth-gcc47.patch
  * leechcraft-monocle-gcc47.patch
  * leechcraft-gcc47.patch
- Removed useless obsoletings.
- Let's recommend set of packages.
- New plugins were enabled:
  * azoth-abbrev provides abbreviations via commands like /abbrev
    for LeechCraft Azoth;
  * intermutko provides a HTTP Accept-Language header configurator;
  * lmp-potorchu provides visualization effects
    for LeechCraft audio player;
  * zalil allows to upload files to accountless filebin services.
- Useless Qt5' files removing.
- SLE 12 support.
* Mon Jan 26 2015 dap.darkness@gmail.com
- Disabled plugins:
  * azoth-zheet; MSN support became obsoleted by MSFT.
* Sun Jan 25 2015 crrodriguez@opensuse.org
- Disable azoth-zheet (MSN support) in tumbleweed and later
  as MSN was discontinued by MSFT.
* Wed Sep 10 2014 dap.darkness@gmail.com
- A new plugin was enabled:
  * Eleeminator is a a terminal emulator.
* Wed Jul 30 2014 dap.darkness@gmail.com
- 0.6.70 release:
  * Poshuku browser IDN support was enabled;
  * utilities library was split into different so files
    and subpackages.
- New plugins were enabled:
  * Azoth MuCommands provides conference-oriented commands;
  * LMP FrAdj is a 10-band equalizer;
  * Poshuku DCAC provides DC/AC for browser;
  * Poshuku QRd provides QR codes for browser.
- leechcraft-azoth-gcc47.patch was updated.
- Added leechcraft-gcc47.patch vs. names constructor error.
* Mon Jul  7 2014 dap.darkness@gmail.com
- 0.6.65-380-gffa0f72.tar.xz git snapshot:
  * monocle-postrus became installable out of box (doesn't
    require libspectre now and so isn't affected by bnc#828751).
- New plugins were enabled:
  * LMP BrainSlugz is a audio collection checker;
  * LMP HttStream is a music streamer over http;
  * Poshuku SpeedDial is a speed dial for browser.
- Disabled plugins:
  * azoth-p100q became obsoleted;
  * azoth-otroid can't be built for oS 12.2-;
  * bittorrent requires libtorrent-rasterbar >= 0.16 (oS 13.1+).
* Sat Jun  7 2014 dap.darkness@gmail.com
- udev → libudev, the latest is really needed
  and Factory's udev doesn't require it any more.
* Sat May 17 2014 dap.darkness@gmail.com
- New plugin was enabled for Factory:
  * Aggregator WebAccess is a news reader web interface module.
* Sat Apr  5 2014 dap.darkness@gmail.com
- 0.6.65 release:
  * LMP audio player ReplayGain support;
  * Azoth, the IM client, server history support (XEP-0313);
  * XMPP Message Carbons support (XEP-0280);
  * Monocle, the document reader, now supports annotated documents;
  * PDF seamless scrolling without freezing the UI;
  * The LHTR visual hypertext editor now gained
    support for the image sources plugins (Blasq);
  * HTML editor now supports syntax highlighting;
  * Aggregator now supports renaming feeds;
  * LackMan now supports vim-style navigation
    and using Space key to toggle packages;
  * MusicZombie now fetches all information about a single artist
    in one request;
  * New Life now supports importing history from Opera;
  * Popishu text editor now supports the recoverable tabs concept;
  * SB2 now supports hiding quarks by default;
  * /etc/os-release is now properly parsed.
- New plugins were enabled:
  * CertMgr is the new SSL manager;
  * CPU load is a monitoring quark;
  * Ooronee handles images and text dropped onto it;
  * Rosenthal is a core spell checker.
- Deleted leechcraft-0.6.60-monocle-arm.patch as merged.
- Added leechcraft-monocle-gcc47.patch
  to prevent names constructor error.
- Shellopen plugin amd mediacalls became obsoleted.
* Fri Mar  7 2014 dap.darkness@gmail.com
- Removed velvetbird bcond because of purple
  already built for all OBS archs.
- Added leechcraft-0.6.60-monocle-arm.patch to prevent
  arm6-7 build failures, upstream url:
  https://github.com/0xd34df00d/leechcraft/commit/ef3fdc
- Added gstreamer-1_0 define against oS >= 13.2 and
  versioned gst "BuildConflicts" to build lmp with the
  same gst as QtWebKit was built to prevent runtime freeze.
* Sun Feb 23 2014 dap.darkness@gmail.com
- New plugins were enabled:
  * Azoth Astrality: telepathy framework (Factory);
  * Qrosp: scripting support;
  * Textogroose: scripted lyrics finder.
* Mon Jan  6 2014 dap.darkness@gmail.com
- New mupdf version broke building again
  and upstream decided not to fix it.
* Sat Jan  4 2014 dmueller@suse.com
- add velvetbird buildconditional to consolidate and correct
  arch dependencies (fixes build)
* Mon Dec 30 2013 dap.darkness@gmail.com
- 0.6.60 release:
  * Desktop mode provides a full-featured desktop environment;
  * LMP social collection-oriented audio player improvements;
  * See more at http://leechcraft.org/leechcraft-0.6.60-is-released
- New plugins were enabled:
  * Azoth Murm: VK.com (VKontakte) api messaging support;
  * Azoth WoodPecker: Twitter support;
  * Blasq is a new plugin for cloud image photo albums;
  * Devmon for managing non-mass storage USB devices;
  * Fenet is responsible for autostarting a window manager;
  * Harbinger provides a collections manager plugin;
  * Htthare provides content from local filesystem over LANs;
  * Imgaste for uploading images to imagebins;
  * Krigstask provides a taskbar and a pager quark for SB2;
  * Laughty is a system-wide desktop notifications daemon;
  * LMP MTPSync, LMP subplugin for uploading music via MTP;
  * Mellonetray provides a system tray area quark for SB2;
  * Monocle Dil contains a MOBI subplugin for documents viewer;
  * Scroblibre, a Submissions API 1.2-compliant scrobbler;
  * Sysnotify, a notification backend using the libnotify D-Bus;
  * VtyuLC, experimental VLC-based video player;
  * Xtazy for fetching currently playing tune from players.
- Maintainership:
  * Removed leechcraft-otlozhu-0.6.0-cpp.patch;
  * Added leechcraft-azoth-gcc47.patch vs. oS 12.2' gcc issue;
  * %%%%make_jobs was switched back because it requires kde;
  * Build requirements were replaced by pkgconfig();
  * cmake section was refactored again.
* Sat Dec 21 2013 dap.darkness@gmail.com
- Added leechcraft-otlozhu-0.6.0-cpp.patch to prevent strange
  build issue: "error: no type named 'type' in 'struct",
  https://github.com/0xd34df00d/leechcraft/commit/170e8
- make_jobs, ix86 and arm macros became used.
- choroid, hotsensors, shaitan and syncer plugins
  became obsoleted because of ustream request.
* Fri Sep 27 2013 dap.darkness@gmail.com
- _constraints was added to prevent out-of-memory build issue.
* Wed Sep 11 2013 dap.darkness@gmail.com
- 0.6.0 release fixes lots of bugs in
  * Core, Util & XSD,
  * AdvancedNotifications,
  * Aggregator,
  * Azoth, Azoth AdiumStyles, Azoth Autoidler,
    Azoth p100q, Azoth Vader & Azoth Xoox,
  * Dolozhee (set proper stretch on widgets),
  * LastFMScrobble (fixed leaking),
  * Launchy (use own settings instead of messing with LMP),
  * Liznoo (try autostarting UPower if it's unavailable),
  * LMP & LMP Graffiti,
  * Poshuku & Poshuku CleanWeb,
  * Summary (fixed leaking context menu actions).
- Spec fixing up:
  * Obsoletes nacheku because of ustream request.
  * DSTRICT_LICENSING=True to suggest IM clients icons.
  * DENABLE_MEDIACALLS=True to enable Jingle support.
  * DENABLE_BITTORRENT_GEOIP=True to enable countries flags.
* Fri Jul 12 2013 dap.darkness@gmail.com
- 0.5.99 bugfix release:
  * AN: fixed a typo in user string.
  * AN: updated English and Russian translations.
  * Azoth: auto-request logs for MUC participants as well.
  * Azoth: fixed font zooming in fixed-font MUCs.
  * Azoth CH: don't test the entry type, leave that to core.
  * LMP: fixed a segfault on removable device removal in sync widget.
  * Lemon: added Qwt 6.1 compatibility.
  * Liznoo: added Qwt 6.1 compatibility.
  * Monocle Mu: depend on openjpeg and jbig2dec, required by mupdf.
  * Poshuku CleanWeb: fixed a rare segfault.
- openSUSE 12.1 became EOL and unsupported by upstream:
  * leechcraft-acetamide-qt47.patch was deleted;
  * if-sections were deleted;
  * gcc version required to build was incremented.
- Forgotten doc dependencies were deleted (doxygen, graphviz).
- Additional mupdf linking dependencies were added (jbig2dec, openjpeg).
- Conflict with Lcms 2.5+ was added as a workaround for bnc#828751.
* Mon Jun 24 2013 dap.darkness@gmail.com
- 0.5.98 bugfix release:
  * Core: first show unassociated dock widgets.
  * Core: fixed some segfaults on tab closes.
  * Core: fixed notifications about current tab changes.
  * Core: fixed reusing IDs for jobs.
  * AN: fixed overlay text drawing on notification icons.
  * Aggregator: always save provider for delegated jobs.
  * Aggregator: download the rest of the feeds after killing a stall.
  * Azoth: fixed several rare segfaults.
  * Azoth: don't try sending contact ID to another on DnD.
  * Azoth: change tab name after entry renaming.
  * Azoth MetaContacts: don't suggest unifying with MUC entries.
  * Azoth Xoox: properly handle server errors on form fetching.
  * Kinotify: fixed leaking state machine on each notification.
  * LMP: fixed broken synchronization symbol fixing.
  * LMP: temporary files are always removed after sync.
  * LMP: metadata is now mapped properly from the source.
  * Monocle: only render those pages that are actually visible.
  * Monocle: don't set negative scales.
  * Monocle: menu is shown only if mouse moved with a button pressed.
  * Monocle Seen: safeguard against rendering a bunch of small images.
  * TSM: fixed occasional segfaults on tab closes.
  * Vrooby: proper partition naming in UDisks2 backend.
- Fixed for PowerPC and ARM architectures:
  * no v8 and mupdf for ppc* — monocle-mu plugin was disabled;
  * no libpurple for armv5 — azoth-velvetbird plugin was disabled.
- Removed leechcraft-doc-doxygen-rpmlint-w.patch: resolved in upstream.
- Qt >= 4.8 became required to build.
* Mon Jun 10 2013 dap.darkness@gmail.com
- 0.5.97 bugfix release:
  * Core: fixed colors for QML buttons (mucn neater now).
  * Core: properly handle META key in shortcuts dialog.
  * Core: properly set default string codec, fixes debug messages encoding.
  * Util: fixed memory leak with QML and ColorThemeProxy.
  * Util: fixed rectangle fitting algorithm.
  * Azoth: fixed chat entry destruction on chat tab close.
  * HotSensors: take text color from the QML theme.
  * LackMan: fixed a typo in SQL query.
  * Launchy: extended known category aliases for Multimedia.
  * Monocle: keep page position on resize.
  * NSM: fixed icons for tab context menu actions.
  * TPI: update job name as well.
  * TPI: don't show internal tasks.
  * Vrooby: close the device popup on hoverout.
- New plugins were enabled for Factory:
  * Touchstreams — VK.com music streaming.
* Tue May 21 2013 dap.darkness@gmail.com
- 0.5.96 bugfix release:
  * Core: keep tab icon along tab moves between windows.
  * Core: fixed toolbar handling on tab moves between windows.
  * Core: fixed file locking threading issues.
  * Core: fixed network disk cache expiration handling.
  * Core: proper handling of forcefully closed unassociated dock widgets.
  * Core: don't show actions with empty text in popup menus.
  * Azoth: fixed autoscrolling.
  * Azoth: application-wide users list shortcut.
  * Azoth: case-insensitive users list filtering.
  * Azoth: use proper icon for voice calls.
  * Azoth Acetamide: made the channels list dialog non-modal.
  * Azoth Acetamide: allow joining to channels while the list is fetched.
  * Blogique: fixed progress indicator.
  * Blogique Hestia: fixed autoupdating entries in local blog.
  * Monocle Postrus: fixed FindLibSpectre.cmake for upcoming CMake.
  * LMP: fix rare segfaults on queue clearing.
  * LMP: clear last song data on player clearing.
  * LMP: support drags from filesystem browser.
  * LMP: replace queue on playlist activation.
  * LMP: properly restore play mode check state.
  * Popishu: fixed caret line background color.
  * VB: don't own conversation by the buddy, fixes multiple segfaults.
- New plugins were enabled:
  * azoth-otroid — Off-the-Record module for IM;
  * monocle-mu — another pdf module via the mupdf backend;
- Renamed to correspond upstream naming policy:
  * poshuku-delicious => poshuku-onlinebookmarks-delicious;
  * poshuku-readitlater => poshuku-onlinebookmarks-readitlater;
- Updated leechcraft-acetamide-qt47.patch to revert some 0.5.96 changes
  to provide azoth-acetamide plugin at openSUSE 12.1.
- Added "-Doverride=" CXX-flag to prevent compiler errors at openSUSE 12.1.
- Fixed up via `spec-cleaner`.
* Sun Apr 28 2013 dap.darkness@gmail.com
- 0.5.95 release:
  * Aggregator module got a major speedup;
  * Azoth IM client became more keyboard-friendly;
  * Blogique, the blog client, now supports
  - autosaving,
  - tab unclosing,
  - session management with the TabSessManager plugin,
  - showing recent comments and inbox messages;
  * Choroid plugin requires Qt >= 4.8;
  * GActs now bundles a patched Qxt with it. It adds support for assigning
    media keys to global shortcuts, a thing that upstream Qxt misses (and
    seems to not accept the proposed patch for several years already);
  * GMail Notifier module now supports showing a quark at SB2.
  * Sidebar plugin became deprecated;
  * Launchy module now supports favorites category;
  * LHTR visual editor plugin now supports tables;
  * License was switched from GPL-3.0+ to BSL-1.0;
  * LMP audio-player got a proper album art manager;
  * Monocle document reader now supports
  - page thumbnails,
  - bookmarks (with visually highlighting the currently displaying area),
  - forms for PDF files,
  - text searching;
  * Multiple windows support;
  * Poshuku history widget got support of
  - filtering by URL,
  - eliminating duplicates in the same section;
  * SB2 now supports placing the panel in any window side;
  * Vrooby now supports UDisks2 and building with several backends.
- New plugins were enabled:
  * azoth-velvetbird — LibPurple wrapper for IM;
  * blogique-hestia — local blogging;
  * hotsensors — temperature sensors for sidebar;
  * lmp-graffiti — audio tags editor for player;
  * monocle-doc — monocle plugin documentation;
  * poshuku-autosearch — autosearch for browser.
- See more at http://leechcraft.org/moving-to-bsl
  and http://leechcraft.org/leechcraft-0.5.95-is-released
- Added leechcraft-acetamide-qt47.patch to revert some 0.5.95 changes
  to provide azoth-acetamide plugin at openSUSE 12.1.
- Added leechcraft-doc-doxygen-rpmlint-w.patch to prevent rpmlint
  "W: file-contains-date-and-time" for doxygen made html-files.
- Removed boost.patch merged by upstream.
* Fri Feb  1 2013 dap.darkness@gmail.com
- A bug with not loading torrent plugin was fixed via boost.patch.
* Fri Dec 21 2012 dap.darkness@gmail.com
- 0.5.90 release:
  * lots of improvements and bugfixes;
  * desktop-files to open different file types;
  * gcc 4.5 support was deprecated.
- New plugins were enabled:
  * azoth-shx — shell command runner;
  * blogique & blogique-metida — blogging;
  * dumbeep — dumb sound notifier;
  * hotstreams — radio streams provider;
  * launchy — third-party application launcher;
  * lemon — another network Monitor;
  * liznoo — power manager;
  * monocle-postrus && monocle-seen — PostScript && Djvu documents support;
  * musiczombie — MusicBrainz.org client;
  * sb2 — another side bar;
  * shaitan — terminal;
  * tpi — quark task progress indicator.
- Clean section was removed.
- Applied into upstream patches were deleted.
- Useless desktop-file was deleted.
* Wed Oct 31 2012 mvyskocil@suse.com
- setup permissions correctly to avoid false duplicates reported by
  rpmlint because of new fdupes behavior (bnc#784670)
* Sun Sep  9 2012 nekolayer@yandex.ru
- fix build with new libqxmpp (backported from git)
* Fri Aug 10 2012 dap.darkness@gmail.com
- 0.5.80 release
  Media player LMP:
  * All proper logic for uploading songs to cloud services
  * Fetching playlists from such services
  * A new plugin has been added - LMP MP3tunes
  * There is now a nice stats label below the playlist
  * There are now different sort modes
  * Among cosmetic changes are fixed background colors in QML elements
  * Support for ignoring "The " when sorting artists in collection
  * And shortcuts for different actions are configurable now, too
  NetStoreManager:
  * A new plugin has been added - NetStoreManager GoogleDrive
  * For now only uploading and fetching the list of uploaded files works
  Document viewer Monocle supports:
  * Displaying one page or double-page spread
  * Copying selection to image or text
  * Scaling
  * Width-fitting
  * Tables of contents
  * Links
  * Paginated navigation
  * Printing
  * Monocle also integrates with the rest of LeechCraft
  * For now only PDF and fb2 file formats are supported
  * PDF is supported via Poppler library
  IM client Azoth:
  * A new plugin has been added - Azoth BirthdayNotifier
  * Azoth now finally displays user's avatar in tooltips
  * Tabs of conferences with unread highlight messages are now marked
  * RSS-reader Aggregator now supports exporting feeds to PDF
  * The issue reporter Dolozhee now supports fetching issue categories
* Wed Jul 11 2012 dap.darkness@gmail.com
- 0.5.75 release
  Media player LMP got the following features:
  * Uploading files from local collection to portable media players
  * Optional transcoding of uploaded files
  * Support for social radio stations like Last.FM radio
  * Obtaining personalized recommendations, recent releases etc
  * Support for MPRIS
  New Modules:
  * Vrooby is a removable storage devices manager
  * Monocle is a modular document viewer
  * Several things were optimized a lot
  * A bunch of minor fixes and enhancements in other plugins
  * A nickname can be inserted by Ctrl+activate it in the roster
  * Azoth ChatHistory module finally got a small calendar widget
  * Links in chat logs are now clickable
* Sun May 27 2012 dap.darkness@gmail.com
- 0.5.70 release
  Media player LMP was all-new rewritten and got such features:
  * Specialization on audio
  * Local collection
  * Static and dynamic playlists
  * Support for external playlists in pls, xspf and m3u8 formats
  * Playback modes: sequential, shuffled and track/album/playlist repeat
  * Scrobbling listened tracks to Last.FM via LastFMScrobble
  * Fetching missing album covers via LastFMScrobble
  * Requests for similar artists via LastFMScrobble
  * Tray icon
  * Core: "back"/"forward" mouse buttons make tabs switching
  * Fixes in AdvancedNotifications module
  In modular IM client Azoth:
  * Added support for /kick and /ban commands
  * Smiles aren't replaced anymore in the middle of the words
  * Added support for hiding and disabling accounts
  * Autopaste module was migrated to the codepad.org
  * Azoth p100q is now more compatible with Adium themes
  * Azoth Xoox now supports adding, editing and removing phones and emails
  * Some MUC reconnection issues were fixed in Azoth Xoox.
  * Azoth Vader module now supports assigning phone numbers to contacts
  * Some problems with authorization handling were fixed in Azoth Vader
* Thu May 24 2012 cfarrell@suse.com
- license update: GPL-3.0+
  COPYING and the majority of source code files now state that leechcraft
  is GPL-3.0 licensed
* Sun Apr 29 2012 nekolayer@yandex.ru
- 0.5.65 release
  New Modules:
  * Dolozhee module (bug reporting and feature requesting tool)
  * KBCraft module (keyboard layout manager)
  * Otlozhu module (simple GTD-inspired TODO manager)
  * XProxy module (advanced proxy configurator)
  * LackMan got a major UI update and general overhaul
  * TabSessManager supports global tab unclosing
  * Azoth Xoox properly caches entity capabilities and vCards
  * Lots of fixes and improvements in Azoth Acetamide
  * Choosing chat window style and its variant became much more handy
  * Azoth Xoox got full support for XEP-0232
  * Azoth got configurable minimal message editor height
  * Auscrie was improved and fixed.
* Thu Mar 15 2012 nekolayer@yandex.ru
- 0.5.60 release
  New Modules:
  * Added Azoth Zheet module (MSN support)
  * Added Azoth Vader module (Mail Agent support)
  * Sidebar module
  * Session manager module (save/restore LC tabs)
  * NetStore manager module (now support Yandex.Disk)
  * GActs module (global hotkeys)
  * Azoth Acetamide support CTCP and vCards
  * Aggregator works with DB in another thread and not block main app
  * Many Imporements in adium style support
  * Now using system oxygen icon theme
* Thu Feb  9 2012 nekolayer@yandex.ru
- 0.5.0 release
  * added magnet scheme support in Bittorent module
  * updated icons
  * Poshuku browser - don't notify about items already existing in Favourites.
  * Azoth Xoox: always initialize message subtype.
  fixed summary description
* Wed Jan 25 2012 nekolayer@yandex.ru
- 0.4.99 release
  * fixed memory leaks on Azoth
  * Lackman update to new format
  * Enabled flash support in Poshuku browser
* Fri Jan 13 2012 nekolayer@yandex.ru
- 0.4.98 release
  * Aggregator storages crash fix
  * IRC plugin fixes
  * Azoth adiumstyles fixes
  fixed modules dependencies in spec
* Tue Dec 27 2011 nekolayer@yandex.ru
- 0.4.97 release
  * Azoth messenger visual fixes
  * bittorrent optimization
  * fixed bookmarks sync
* Sun Dec 11 2011 nekolayer@yandex.ru
- 0.4.96 release
  * Fixes in Azoth AdiumStyles
  * Fixed handling of media players in Azoth Xtazy
  * Authorization issues were fixed in Azoth.
  * moderators are now able to kick participants in Azoth Xoox
* Tue Dec  6 2011 nekolayer@yandex.ru
- Enabled Plugins: LcFTP, Lackman, Gmail, Knowhow, Syncer
- Added Renkoo AdiumStyle to azoth-adiumstyles
- Set QAppStyle to Default from Plastique
- Fix Aspell support
- Fix AnHero plugin
- Remove dbusmanager.patch, not needed
* Mon Dec  5 2011 nlminhtl@gmail.com
- Add eiskaltdcpp-fix-php5-issue.patch - fix resolving
  /usr/bin/php5 dependence
* Tue Nov 29 2011 nlminhtl@gmail.com
- 0.4.95 release
- new packages: pogooglue, delicious, readitlater, isterique
- removing qt-multimedia from dependencies
- optimizing the spec file by using macros
- New features:
- * Support for XEP-0055: Jabber Search in Azoth Xoox.
- * AdvancedNotifications now supports enabling/disabling rules and
  single shot rules.
- * Azoth and Azoth Xoox now support inviting to MUCs.
- * Azoth Acetamide now supports SSL connections.
- * and other features
  http://leechcraft.org/leechcraft-0.4.95-is-released
* Sat Nov 26 2011 nlminhtl@gmail.com
- fixing the bug with azoth style packages in openSUSE:Factory
* Fri Nov 11 2011 nlminhtl@gmail.com
- removing the download service for openSUSE:Factory
- adding dependency aspell-devel for spell checking support
* Sun Oct 23 2011 nlminhtl@gmail.com
- 0.4.90 release
* Thu Jul 21 2011 nlminhtl@gmail.com
- 0.4.85 version release
* Mon Jul  4 2011 nlminhtl@gmail.com
- 0.4.80 version release
* Thu Jun 30 2011 nlminhtl@gmail.com
- package name fixed
